	program comp

c       This program reads in a low-resolution solar spectrum which is
c       well-calibrated in intensity (column 2) and a high resolution
c       solar spectrum which is not (column 3). It renormalizes the
c       high-resolution spectrum to the low-resolution spectrum locally, 
c       using a triangular band pass of FWHM navg.

c	Column 2 is a combination of the solstice/susim spectrum
c	uars_avg_0582.dat and the LOWTRAN7/MODTRAN solar spectrum, merged
c	together from 405.6 to 410.6 nm, in W m-2 nm-1.

c	Column 3 is the KPNO_AFGL solar spectrum from Chance and Spurr, 1997.
c	Ring Effect Studies: Rayleigh Scattering, Including Molecular Parameters
c	for Rotational Raman Scattering, and the Fraunhofer Spectrum, K. Chance
c	and R.J.D. Spurr, Applied Optics 36, 5224-5230, 1997, in photons s-2
c	cm-2 nm-1

	implicit real*8 (a - h, o - z)
	character*40 input, output
	dimension pos (40000), uars (40000)
	real*8 kpno (40000)
	dimension spec (40000)
	dimension ymult (-100:100)
	write (*, '(5x, a)') 'enter filespec of input file.'
	read (*, 10) input
	write (*, '(5x, a)') 'enter filespec of output file.'
	read (*, 10) output
10	format (a)
	open (unit = 1, file = input, status = 'old')
	open (unit = 2, file = output, status = 'unknown')
	write (*, '(5x, a)') 'number of points +- to average'
	read (*, *) navg

c	navg = 100 is a good choice for uars and kpno spectra.
c       It is close to the actual resolution of the uars data.
	denom = dfloat ((navg + 1)**2)

	do i = 1, navg
		ymult (i) = (navg + 1 - i) / denom
		ymult (-i) = ymult (i)
	end do
	ymult (0) = (navg + 1) / denom

	i = 1
20	read (1, *, end = 30) pos (i), uars (i), kpno (i)
		i = i + 1
		go to 20
30	npoints = i - 1

	do i = 1, navg
	   write (2, '(f8.2, 1pe13.5)') pos (i), uars (i)
	end do

	usum = 0.
	ssum = 0.
	do i = navg + 1, npoints - navg
		ynorm1 = 0.d0
		ynorm2 = 0.d0
		ynorm = 0.d0
		do j = - navg, navg
			ynorm1 = ynorm1 + ymult (j) * uars (i + j)
			ynorm2 = ynorm2 + ymult (j) * kpno (i + j)
			ynorm = ynorm1 / ynorm2
c		write (2, *) i, j, ymult (j), ynorm
		end do
		spec (i) = kpno (i) * ynorm
		write (2, '(f8.2, 1pe13.5)') pos (i), spec (i)
		usum = usum + uars (i)
		ssum = ssum + spec (i)
	end do
	write (*, '(1p3e13.5)') usum, ssum, ssum / usum

	do i = npoints - navg + 1, npoints
	   write (2, '(f8.2, 1pe13.5)') pos (i), uars (i)
	end do

	close (unit = 1)
	close (unit = 2)
	stop
	end
