pro get_srf_brewer,slit,w_vac,srf,err_srf,w_vac_cent

; Get normalized Brewer SRF in air and converrt to vacuum wavelengths

; !!! only l1..l6 and m1 and m2  !!!


;	02/15/06 - add midium and long wavelengths slit masks
;From: Alexander Cede <cede@chescat.gsfc.nasa.gov>
; Below are wavelength-centers (air-wavelengths) and slit functions for the low (=ozone) wavelength range (303-320nm) and medium wavelength range (327-343nm). 
;In these 2 ranges we do the polarized sky radiance measurements in the principal plane since 2005-4-21.
;The wavelength-accuracy is 0.015nm (2sigma) for all wavelengths. You can use this number as a totally correlated wavelength uncertainty 
;(i.e. if slit #1 is 0.01nm high, then all other slits are also 0.01nm high; this is because the dominant contribution is the grating-shift due to temperature, mechanical movement etc., which affects all wavelengths in the same way).

;Low range wavelength centers slit #1 to slit #6 [nm]
;303.216  306.315  310.056  313.498  316.794  319.983
;Medium range wavelength centers slit #1 to slit #6 [nm]
;327.454  330.316  333.759  336.913  339.921  342.818

; Slit functions:
;Column 1: Difference from center wavelength [nm]
;Column 2: Normalized slit-function
;The slits are symmetrical, so you can take the data on both sides of the center wavelength

w_diff=fltarr(20) & srfm=w_diff

if slit eq 'l1' then begin 		;Slit function low range, slit #1
w_air_cent=303.216    & print,'w_air_cent=',w_air_cent
w_diff(0)=      0    &  srfm(0)=1.0000
w_diff(1)=    0.0297 &  srfm(1)=   0.9877
w_diff(2)=    0.0595 &  srfm(2)=   0.9620
w_diff(3)=    0.0892 &  srfm(3)=   0.9269
w_diff(4)=    0.1190 &  srfm(4)=   0.8844
w_diff(5)=    0.1487 &  srfm(5)=   0.8358
w_diff(6)=    0.1785 &  srfm(6)=   0.7825
w_diff(7)=    0.2082 &  srfm(7)=   0.7254
w_diff(8)=    0.2379 &  srfm(8)=   0.6655
w_diff(9)=    0.2677 &  srfm(9)=  0.6035
w_diff(10)=    0.2974 &  srfm(10)=   0.5403
w_diff(11)=    0.3272 &  srfm(11)=   0.4764
w_diff(12)=    0.3569 &  srfm(12)=   0.4125
w_diff(13)=    0.3866 &  srfm(13)=   0.3490
w_diff(14)=    0.4164 &  srfm(14)=   0.2865
w_diff(15)=    0.4461 &  srfm(15)=   0.2254
w_diff(16)=    0.4759 &  srfm(16)=   0.1659
w_diff(17)=    0.5056 &  srfm(17)=   0.1083
w_diff(18)=    0.5354 &  srfm(18)=   0.0530
w_diff(19)=    0.5651 &  srfm(19)=        0


end else if slit eq 'l2' then begin 	;Slit function low range, slit #2
w_air_cent= 306.315  & print,'w_air_cent=',w_air_cent
w_diff(0)=         0  & srfm(0)=1.0000
w_diff(1)=    0.0294  & srfm(1)=0.9870
w_diff(2)=    0.0589  & srfm(2)=0.9603
w_diff(3)=    0.0883  & srfm(3)=0.9242
w_diff(4)=    0.1178  & srfm(4)=0.8808
w_diff(5)=    0.1472  & srfm(5)=0.8316
w_diff(6)=    0.1766  & srfm(6)=0.7778
w_diff(7)=    0.2061  & srfm(7)=0.7204
w_diff(8)=    0.2355  & srfm(8)=0.6603
w_diff(9)=    0.2650  & srfm(9)=0.5983
w_diff(10)=    0.2944  & srfm(10)=0.5353
w_diff(11)=    0.3238  & srfm(11)=0.4717
w_diff(12)=    0.3533  & srfm(12)=0.4082
w_diff(13)=    0.3827  & srfm(13)=0.3452
w_diff(14)=    0.4122  & srfm(14)=0.2833
w_diff(15)=    0.4416  & srfm(15)=0.2227
w_diff(16)=    0.4710  & srfm(16)=0.1639
w_diff(17)=    0.5005  & srfm(17)=0.1070
w_diff(18)=    0.5299  & srfm(18)=0.0523
w_diff(19)=    0.5594  & srfm(19)=     0


end else if slit eq 'l3' then begin 		; Slit function low range, slit #3
w_air_cent=  310.056  & print,'w_air_cent=',w_air_cent
w_diff(0)=         0  & srfm(0)=1.0000
w_diff(1)=    0.0290  & srfm(1)=0.9849
w_diff(2)=    0.0581  & srfm(2)=0.9556
w_diff(3)=    0.0871  & srfm(3)=0.9170
w_diff(4)=    0.1161  & srfm(4)=0.8715
w_diff(5)=    0.1452  & srfm(5)=0.8206
w_diff(6)=    0.1742  & srfm(6)=0.7655
w_diff(7)=    0.2032  & srfm(7)=0.7074
w_diff(8)=    0.2323  & srfm(8)=0.6470
w_diff(9)=    0.2613  & srfm(9)=0.5851
w_diff(10)=    0.2903  & srfm(10)=0.5225
w_diff(11)=    0.3194  & srfm(11)=0.4597
w_diff(12)=    0.3484  & srfm(12)=0.3973
w_diff(13)=    0.3774  & srfm(13)=0.3356
w_diff(14)=    0.4064  & srfm(14)=0.2752
w_diff(15)=    0.4355  & srfm(15)=0.2162
w_diff(16)=    0.4645  & srfm(16)=0.1590
w_diff(17)=    0.4935  & srfm(17)=0.1038
w_diff(18)=    0.5226  & srfm(18)=0.0507
w_diff(19)=    0.5516  & srfm(19)=     0


end else if slit eq 'l4' then begin 		; Slit function low range, slit #4
w_air_cent= 313.498 & print,'w_air_cent=',w_air_cent
w_diff(0)=         0  & srfm(0)=1.0000
w_diff(1)=    0.0295  & srfm(1)=0.9864
w_diff(2)=    0.0591  & srfm(2)=0.9590
w_diff(3)=    0.0886  & srfm(3)=0.9222
w_diff(4)=    0.1182  & srfm(4)=0.8782
w_diff(5)=    0.1477  & srfm(5)=0.8285
w_diff(6)=    0.1772  & srfm(6)=0.7743
w_diff(7)=    0.2068  & srfm(7)=0.7167
w_diff(8)=    0.2363  & srfm(8)=0.6565
w_diff(9)=    0.2659  & srfm(9)=0.5946
w_diff(10)=    0.2954  & srfm(10)=0.5316
w_diff(11)=    0.3249  & srfm(11)=0.4683
w_diff(12)=    0.3545  & srfm(12)=0.4051
w_diff(13)=    0.3840  & srfm(13)=0.3425
w_diff(14)=    0.4136  & srfm(14)=0.2810
w_diff(15)=    0.4431  & srfm(15)=0.2209
w_diff(16)=    0.4726  & srfm(16)=0.1625
w_diff(17)=    0.5022  & srfm(17)=0.1061
w_diff(18)=    0.5317  & srfm(18)=0.0519
w_diff(19)=    0.5613  & srfm(19)=     0

end else if slit eq 'l5' then begin 		; Slit function low range, slit #5
w_air_cent= 316.794  & print,'w_air_cent=',w_air_cent
w_diff(0)=        0   & srfm(0)=1.0000
w_diff(1)=    0.0291  & srfm(1)= 0.9842
w_diff(2)=    0.0583  & srfm(2)=0.9540
w_diff(3)=    0.0874  & srfm(3)=0.9146
w_diff(4)=    0.1165  & srfm(4)=0.8684
w_diff(5)=    0.1457  & srfm(5)=0.8169
w_diff(6)=    0.1748  & srfm(6)=0.7615
w_diff(7)=    0.2039  & srfm(7)=0.7031
w_diff(8)=    0.2331  & srfm(8)=0.6426
w_diff(9)=    0.2622  & srfm(9)=0.5808
w_diff(10)=    0.2914  & srfm(10)=0.5184
w_diff(11)=    0.3205  & srfm(11)=0.4559
w_diff(12)=    0.3496  & srfm(12)=0.3938
w_diff(13)=    0.3788  & srfm(13)=0.3326
w_diff(14)=    0.4079  & srfm(14)=0.2725
w_diff(15)=    0.4370  & srfm(15)=0.2141
w_diff(16)=    0.4662  & srfm(16)=0.1574
w_diff(17)=    0.4953  & srfm(17)=0.1027
w_diff(18)=    0.5244  & srfm(18)=0.0502
w_diff(19)=    0.5536  & srfm(19)=  0

end else if slit eq 'l6' then begin 		; Slit function low range, slit #6
w_air_cent= 319.983   & print,'w_air_cent=',w_air_cent
w_diff(0)=       0    & srfm(0)= 1.0000
w_diff(1)=    0.0287  & srfm(1)=  0.9827
w_diff(2)=    0.0573  & srfm(2)=  0.9508
w_diff(3)=    0.0860  & srfm(3)=  0.9098
w_diff(4)=    0.1147  & srfm(4)=  0.8623
w_diff(5)=    0.1433  & srfm(5)=  0.8098
w_diff(6)=    0.1720  & srfm(6)=  0.7537
w_diff(7)=    0.2007  & srfm(7)=  0.6948
w_diff(8)=    0.2294  & srfm(8)=  0.6342
w_diff(9)=    0.2580  & srfm(9)=  0.5726
w_diff(10)=    0.2867  & srfm(10)=  0.5105
w_diff(11)=    0.3154  & srfm(11)=  0.4485
w_diff(12)=    0.3440  & srfm(12)=  0.3871
w_diff(13)=    0.3727  & srfm(13)=  0.3267
w_diff(14)=    0.4014  & srfm(14)=  0.2676
w_diff(15)=    0.4300  & srfm(15)=  0.2101
w_diff(16)=    0.4587  & srfm(16)=  0.1544
w_diff(17)=    0.4874  & srfm(17)=  0.1007
w_diff(18)=    0.5161  & srfm(18)=  0.0492
w_diff(19)=    0.5447  & srfm(19)=       0

;Medium range center wavelengths (air):
;327.454  330.316  333.759  336.913  339.921  342.818

end else if slit eq 'm1' then begin 		; Slit function mid range, slit #1
w_air_cent= 327.454   & print,'w_air_cent=',w_air_cent
;Medium range slit #1
;    -0.5391         0
;    -0.5107    0.0496
;    -0.4823    0.1015
;    -0.4540    0.1556
;    -0.4256    0.2116
;    -0.3972    0.2695
;    -0.3688    0.3290
;    -0.3405    0.3897
;    -0.3121    0.4514
;    -0.2837    0.5136
;    -0.2554    0.5758
;    -0.2270    0.6375
;    -0.1986    0.6981
;    -0.1702    0.7568
;    -0.1419    0.8126
;    -0.1135    0.8647
;    -0.0851    0.9117
;    -0.0567    0.9521
;    -0.0284    0.9833
;          0    1.0000
w_diff(0)=       0    & srfm(0)= 1.0000
w_diff(1)=    0.0284  & srfm(1)=  0.9833
w_diff(2)=    0.0567  & srfm(2)=  0.9521
w_diff(3)=    0.0851  & srfm(3)=  0.9117
w_diff(4)=    0.1135  & srfm(4)=  0.8647
w_diff(5)=    0.1419  & srfm(5)=  0.8126
w_diff(6)=    0.1702  & srfm(6)=  0.7568
w_diff(7)=    0.1986  & srfm(7)=  0.6981
w_diff(8)=    0.2270  & srfm(8)=  0.6375
w_diff(9)=    0.2554  & srfm(9)=  0.5758
w_diff(10)=    0.2837  & srfm(10)=  0.5136
w_diff(11)=    0.3121  & srfm(11)=  0.4514
w_diff(12)=    0.3405  & srfm(12)=  0.3897
w_diff(13)=    0.3688  & srfm(13)=  0.3290
w_diff(14)=    0.3972  & srfm(14)=  0.2695
w_diff(15)=    0.4256  & srfm(15)=  0.2116
w_diff(16)=    0.4540  & srfm(16)=  0.1556
w_diff(17)=    0.4823  & srfm(17)=  0.1015
w_diff(18)=    0.5107  & srfm(18)=  0.0496
w_diff(19)=    0.5391  & srfm(19)=       0

end else if slit eq 'm2' then begin 		; Slit function mid range, slit #2
w_air_cent= 330.316   & print,'w_air_cent=',w_air_cent
;Medium range slit #2
;    -0.5329         0
;    -0.5048    0.0490
;    -0.4768    0.1002
;    -0.4487    0.1537
;    -0.4207    0.2091
;    -0.3926    0.2663
;    -0.3646    0.3252
;    -0.3365    0.3854
;    -0.3085    0.4467
;    -0.2805    0.5085
;    -0.2524    0.5705
;    -0.2244    0.6321
;    -0.1963    0.6928
;    -0.1683    0.7517
;    -0.1402    0.8080
;    -0.1122    0.8607
;    -0.0841    0.9086
;    -0.0561    0.9499
;    -0.0280    0.9823
;          0    1.0000
w_diff(0)=       0    & srfm(0)= 1.0000
w_diff(1)=    0.0280  & srfm(1)=  0.9823
w_diff(2)=    0.0561  & srfm(2)=  0.9499
w_diff(3)=    0.0841  & srfm(3)=  0.9086
w_diff(4)=    0.1122  & srfm(4)=  0.8607
w_diff(5)=    0.1402  & srfm(5)=  0.8080
w_diff(6)=    0.1683  & srfm(6)=  0.7517
w_diff(7)=    0.1963  & srfm(7)=  0.6928
w_diff(8)=    0.2244  & srfm(8)=  0.6321
w_diff(9)=    0.2524  & srfm(9)=  0.5705
w_diff(10)=    0.2805  & srfm(10)=  0.5085
w_diff(11)=    0.3085  & srfm(11)=  0.4467
w_diff(12)=    0.3365  & srfm(12)=  0.3854
w_diff(13)=    0.3646  & srfm(13)=  0.3252
w_diff(14)=    0.3926  & srfm(14)=  0.2663
w_diff(15)=    0.4207  & srfm(15)=  0.2091
w_diff(16)=    0.4487  & srfm(16)=  0.1537
w_diff(17)=    0.4768  & srfm(17)=  0.1002
w_diff(18)=    0.5048  & srfm(18)=  0.0490
w_diff(19)=    0.5329  & srfm(19)=       0


end    

w_air=fltarr(39) & srf=w_air & err_srf=w_air

for i=0,18 do begin 
w_air(i)=w_air_cent - w_diff(19-i)
srf  (i)=srfm(19-i)
err_srf(i)=0.0
w_air(i+20)=w_air_cent + w_diff(i+1)
srf  (i+20)=srfm(i+1)
err_srf(i+20)=0.0
endfor
w_air(19)=w_air_cent
srf  (19)=srfm(0)
err_srf(19)=0.0

airvac,w_air,w_vac	; shift to vac wavelengths

w_vac_cent=w_vac(19) &  print,'w_vac_cent=',w_vac_cent 

;openw,2,slit+'.air' & printf,2,slit &  for i=0,n_elements(w_air)-1 do printf,2,w_air(i),srf(i) &  close,2
;openw,2,slit+'.vac' & printf,2,slit &  for i=0,n_elements(w_vac)-1 do printf,2,w_vac(i),srf(i) &  close,2


return
end
;		TEST
;From cede@gsfc.nasa.gov  Wed Feb 15 08:55:03 2006
;Here the slit functions for
;
;Medium range center wavelengths (air):
;327.454  330.316  333.759  336.913  339.921  342.818
;w_vac_eff=       
;327.5494 330.38779
;High range center wavelengths (air):
;348.831  351.466  354.625  357.505  360.239  362.859	- Cede: low
;
;Here the convoluted SUSIM for all ranges (low, medium, high are rows 1 to 3)
;712.51   607.99   484.63   732.88   745.26   831.07
;998.01  1053.20   898.11   788.95  1125.09  1061.25	- Cede: mid
;0.99780 1.054363
;953.64   967.30  1169.84   939.94  1071.49  1173.18	- Cede: high

;Rayleigh for all ranges, pressure=1011.6mbar (low, medium, high are rows 1 to 3)
;1.1609   1.1114   1.0545   1.0058   0.9617   0.9215	- Cede: low   
;0.8353   0.8052   0.7702   0.7403   0.7127   0.6875	- Cede: medium
;slit_aver: tau_ray_eff, pressure 1013.25mb
;0.834781 0.804636
;0.6390   0.6188   0.5960   0.5760   0.5580   0.5413	- Cede: high

;O2O2 for all ranges, pressure=1011.6mbar (low, medium, high are rows 1 to 3)
;0.0000   0.0000   0.0000   0.0000   0.0000   0.0000
;0.0001   0.0001   0.0002   0.0004   0.0006   0.0016
;0.0002   0.0004   0.0009   0.0028   0.0056   0.0018

;O3 for all ranges, 315DU (low, medium, high are rows 1 to 3)
;1.8778   1.2938   0.7276   0.4925   0.2735   0.2136
;0.0639   0.0424   0.0361   0.0191   0.0104   0.0029
;slit_aver: tau_oz_eff=     
;0.063754 0.04208

;0.0008   0.0026   0.0003   0.0002   0.0003   0.0000
;
;SO2 for all ranges, 2DU (low, medium, high are rows 1 to 3)
;0.0139   0.0270   0.0098   0.0082   0.0045   0.0026
;0.0004   0.0000   0.0000   0.0000   0.0000   0.0000
slit_aver: gammav_eff=      
0.146276
;0.0000   0.0000   0.0000   0.0000   0.0000   0.0000

;NO2 for all ranges, 0.5DU (low, medium, high are rows 1 to 3)
;0.0021   0.0021   0.0025   0.0027   0.0030   0.0034
;0.0039   0.0042   0.0045   0.0048   0.0051   0.0048
;0.0067   0.0061   0.0074   0.0075   0.0064   0.0070

;BrO for all ranges, 0.005DU (low, medium, high are rows 1 to 3)
;0.0003   0.0003   0.0008   0.0011   0.0008   0.0003
;0.0003   0.0011   0.0018   0.0003   0.0006   0.0006
;0.0010   0.0003   0.0008   0.0001   0.0004   0.0002

;HCHO for all ranges, 3DU (low, medium, high are rows 1 to 3)
;0.0038   0.0028   0.0012   0.0017   0.0046   0.0010
;0.0020   0.0025   0.0001   0.0003   0.0026   0.0015
;0.0001   0.0001   0.0008   0.0000   0.0000   0.0000

;OClO for all ranges, 0.0005DU (low, medium, high are rows 1 to 3)
;0.0000   0.0000   0.0000   0.0000   0.0001   0.0000
;0.0000   0.0001   0.0000   0.0001   0.0000   0.0001
;0.0000   0.0002   0.0000   0.0001   0.0001   0.0000

;ClO for all ranges, 0.005DU (low, medium, high are rows 1 to 3)
;0.0001   0.0000   0.0000   0.0000   0.0000   0.0000
;0.0000   0.0000   0.0000   0.0000   0.0000   0.0000
;0.0000   0.0000   0.0000   0.0000   0.0000   0.0000

Medium range slit #3
    -0.5221         0
    -0.4947    0.0478
    -0.4672    0.0978
    -0.4397    0.1500
    -0.4122    0.2042
    -0.3847    0.2603
    -0.3573    0.3180
    -0.3298    0.3772
    -0.3023    0.4376
    -0.2748    0.4988
    -0.2473    0.5603
    -0.2198    0.6217
    -0.1924    0.6824
    -0.1649    0.7418
    -0.1374    0.7989
    -0.1099    0.8529
    -0.0824    0.9023
    -0.0550    0.9457
    -0.0275    0.9803
          0    1.0000

Medium range slit #4
    -0.5337   -0.0000
    -0.5056    0.0481
    -0.4775    0.0985
    -0.4495    0.1510
    -0.4214    0.2055
    -0.3933    0.2619
    -0.3652    0.3199
    -0.3371    0.3794
    -0.3090    0.4400
    -0.2809    0.5013
    -0.2528    0.5630
    -0.2247    0.6245
    -0.1966    0.6852
    -0.1685    0.7444
    -0.1405    0.8013
    -0.1124    0.8550
    -0.0843    0.9040
    -0.0562    0.9468
    -0.0281    0.9809
          0    1.0000

Medium range slit #5
    -0.5235         0
    -0.4960    0.0468
    -0.4684    0.0957
    -0.4409    0.1468
    -0.4133    0.1999
    -0.3858    0.2550
    -0.3582    0.3117
    -0.3307    0.3700
    -0.3031    0.4296
    -0.2756    0.4901
    -0.2480    0.5512
    -0.2204    0.6124
    -0.1929    0.6732
    -0.1653    0.7329
    -0.1378    0.7907
    -0.1102    0.8456
    -0.0827    0.8965
    -0.0551    0.9417
    -0.0276    0.9784
          0    1.0000

Medium range slit #6
    -0.5141         0
    -0.4871    0.0459
    -0.4600    0.0939
    -0.4329    0.1440
    -0.4059    0.1962
    -0.3788    0.2503
    -0.3518    0.3062
    -0.3247    0.3637
    -0.2976    0.4225
    -0.2706    0.4825
    -0.2435    0.5431
    -0.2165    0.6041
    -0.1894    0.6649
    -0.1624    0.7248
    -0.1353    0.7832
    -0.1082    0.8391
    -0.0812    0.8912
    -0.0541    0.9379
    -0.0271    0.9765
          0    1.0000

High range slit #1
    -0.5146         0
    -0.4875    0.0465
    -0.4605    0.0951
    -0.4334    0.1459
    -0.4063    0.1987
    -0.3792    0.2534
    -0.3521    0.3098
    -0.3250    0.3679
    -0.2979    0.4272
    -0.2709    0.4875
    -0.2438    0.5484
    -0.2167    0.6096
    -0.1896    0.6703
    -0.1625    0.7301
    -0.1354    0.7881
    -0.1083    0.8434
    -0.0813    0.8947
    -0.0542    0.9404
    -0.0271    0.9778
          0    1.0000

High range slit #2
    -0.5080   -0.0000
    -0.4812    0.0458
    -0.4545    0.0939
    -0.4278    0.1440
    -0.4010    0.1961
    -0.3743    0.2502
    -0.3476    0.3061
    -0.3208    0.3636
    -0.2941    0.4224
    -0.2674    0.4823
    -0.2406    0.5430
    -0.2139    0.6040
    -0.1871    0.6647
    -0.1604    0.7247
    -0.1337    0.7831
    -0.1069    0.8390
    -0.0802    0.8911
    -0.0535    0.9378
    -0.0267    0.9765
          0    1.0000

High range slit #3
    -0.4945         0
    -0.4685    0.0451
    -0.4424    0.0923
    -0.4164    0.1416
    -0.3904    0.1929
    -0.3644    0.2462
    -0.3383    0.3013
    -0.3123    0.3581
    -0.2863    0.4163
    -0.2603    0.4757
    -0.2342    0.5359
    -0.2082    0.5967
    -0.1822    0.6574
    -0.1562    0.7176
    -0.1301    0.7764
    -0.1041    0.8331
    -0.0781    0.8863
    -0.0521    0.9344
    -0.0260    0.9748
          0    1.0000

High range slit #4
    -0.5078         0
    -0.4811    0.0446
    -0.4544    0.0913
    -0.4277    0.1401
    -0.4009    0.1909
    -0.3742    0.2437
    -0.3475    0.2983
    -0.3207    0.3547
    -0.2940    0.4125
    -0.2673    0.4715
    -0.2406    0.5315
    -0.2138    0.5921
    -0.1871    0.6529
    -0.1604    0.7131
    -0.1336    0.7722
    -0.1069    0.8293
    -0.0802    0.8832
    -0.0535    0.9322
    -0.0267    0.9736
          0    1.0000

High range slit #5
    -0.4953         0
    -0.4693    0.0435
    -0.4432    0.0892
    -0.4171    0.1368
    -0.3911    0.1866
    -0.3650    0.2383
    -0.3389    0.2919
    -0.3128    0.3472
    -0.2868    0.4041
    -0.2607    0.4624
    -0.2346    0.5219
    -0.2086    0.5821
    -0.1825    0.6427
    -0.1564    0.7032
    -0.1304    0.7629
    -0.1043    0.8210
    -0.0782    0.8763
    -0.0521    0.9272
    -0.0261    0.9710
          0    1.0000

High range slit #6
    -0.4854         0
    -0.4598    0.0427
    -0.4343    0.0875
    -0.4087    0.1343
    -0.3832    0.1831
    -0.3576    0.2339
    -0.3321    0.2867
    -0.3065    0.3412
    -0.2810    0.3974
    -0.2555    0.4551
    -0.2299    0.5141
    -0.2044    0.5740
    -0.1788    0.6345
    -0.1533    0.6951
    -0.1277    0.7552
    -0.1022    0.8140
    -0.0766    0.8704
    -0.0511    0.9229
    -0.0255    0.9687
          0    1.0000



________________________________
Alexander Cede
Science Systems & Applications Inc.
NASA/Goddard Space Flight Center
Tel work: +1-301-614-6008
Tel home: +1-240-486-0626
cede@gsfc.nasa.gov 


