pro read_so2,fname,mode,n_col,n_rows,n_header,T,w_units,l_v,so2v

;	INPUT
;	fname - input file name
; 	mode - if eq 'temp_coeff' then read temp coefficicnts and calculate so2v=C0 + c1 (TK-273) + c2^2*(TK-273)^2
;       n_col - number of columns
;	n_row - number of rows
; 	n_heasder - number of header rows
;	T - SO2 temperatures, K ( in case temperature coefficicents are )
;  	w_units  - either Angstrom or nm

;	OUTPUT
; l_v - SO2 absorption coefficient vac wavelengths [nm]
; so2v - SO2 absorption coefficient [atm-cm-1]   at temperature T
;The US Standard Atmosphere (1976) air temperatures for the 3 SO2 retrieval levels are:
;800 mb  2 km    275K
;540 mb  5 km    255K
;120 mb  15 km   217K


IF mode eq 'temp_coeff' THEN begin 

print,'read_so2: temp_coeff'


;From: Kai Yang <Kai.Yang.1@gsfc.nasa.gov> ^M
;Subject: Re: SO2 Absorption Coefficient ^M
;Greetings,^M
;The SO2 Cross section was pointed to me by Nick (See <<http://iup.physik.uni-bremen.de/gruppen/molspec/index.html>><http://iup.physik.uni-bremen.de/gruppen/molspec/index.html)>. ^M
;This cross section was converted to absorption coefficient and then used in spectral fitting algorithm to derive SO2 slant column. ^M
;The spectral resolution is 0.21 nm (FWHM) according to the description in the data set. This resolution is finer than that of OMI, but was used in producing the first results without any degradation. ^M
;As an improvement, I have generated a set of new coefficients (see attachment) at the OMI resolution to be used later on in the spectral fitting method.^M
;Regards.^M
;^M
;^M
;     wl(nm)        c0                 c1 * ( K-273.15)      c2*( K-273.15)^2^M
;      308.      5.22697282257939      0.00706153346690      5.07840329118424e-7^M
;     308.1      5.66223939258775      0.00634371295384      7.60060025740408e-6^M
;     308.2      6.36342090121002      0.00493169491320      0.00001840549157^M
;     ...
;     365.
close,2 & openr,2,fname & so2_dat=dblarr(n_col,n_rows)
;close,2 & openr,2,'SCIAMACHY_PFM_SO2_Absorption_TCelsius_FWHM38_coef.txt' & so2_dat=dblarr(4,571)
x='' & for i=0,n_header-1 do readf,2,x & readf,2,so2_dat & close,2 & print,x
l_v=1.00*reform(so2_dat(0,*)) & ml_v=n_elements(l_v) &  print,'ml_v=',ml_v
if w_units eq 'Angstrom' then l_v=0.1*l_v
c0 =1.00*reform(so2_dat(1,*)) 
c1 =1.00*reform(so2_dat(2,*)) 
c2 =1.00*reform(so2_dat(3,*)) 

TK=float(T) & print,'T=',TK & TC=TK-273.15D+00 &  so2v=(c0 + c1*TC	+ c2*TC*TC)   ;       convert x-section to abs_coeff at temperature TC [atm-cm-1]

ENDIF ELSE BEGIN

print,'read_so2: cross section:'

;vac wav[A] (McGee and Burris shifted to vac) So2 x-section [cm-2]
;with added ??? after 320nm       from OMI SO2 LUT: /omi/home/krotkov/OMISO2/LUT_GEN/gas2_sasha.coe
;2901.33  8.373E-19
;2901.58  8.145E-19
;...
;     3108.00  3.89700e-19
;     3108.30  3.47200e-19
;     3108.60  3.37800e-19
;     3108.90  3.26100e-19
;     3109.20  2.98700e-19
;     3109.50  2.75700e-19
;     3109.80  2.64400e-19
;     3110.10  2.55300e-19
;     3110.40  2.71300e-19
;     3110.70  2.82000e-19
;     3111.00  2.57500e-19
;     3111.30  2.51100e-19
;     3111.60  2.58400e-19
;     3111.90  2.36700e-19
;     3112.20  2.16100e-19
;     3112.50  2.15000e-19
;     3112.80  2.15000e-19
;     3113.10  2.15500e-19
;     3113.40  2.06300e-19
;     3113.70  1.88400e-19
;     3114.00  1.74600e-19
;     3114.30  1.62600e-19
;     3114.60  1.61100e-19
;     3114.90  1.56100e-19
;     3115.20  1.31700e-19
;     3115.50  1.24400e-19
;     3115.80  1.22200e-19
;     3116.10  1.22000e-19
;     3116.40  1.10200e-19
;     3116.70  9.68600e-20
;     3117.00  9.89000e-20
;     3117.30  1.04800e-19
;     3117.60  1.02500e-19
;     3117.90  9.56300e-20
;     3118.20  9.87500e-20
;     3118.50  9.61000e-20
;     3118.80  9.90500e-20
;     3119.10  1.06600e-19
;     3119.40  1.10600e-19
;     3119.70  1.20600e-19
;     3120.00  1.27500e-19
;     3120.30  1.27900e-19
; ...
;     4009.93  2.00000e-24
;close,2 & openr,2,'so2_sasha.coe' & so2_dat=dblarr(2,3091)
;x='' & for i=0,0 do readf,2,x & readf,2,so2_dat & close,2 & print,x
;l_v=0.10*reform(so2_dat(0,*)) & ml_so2v=n_elements(l_so2v) &  print,'ml_so2v=',ml_so2v
; Nlosch=2.686745D+19  &  so2v=Nlosch*reform(so2_dat(1,*))       ;       convert x-section to abs_coeff [atm-cm-1]


;	Bogumil SCIAMATCHY SO2 xsections  <<http://iup.physik.uni-bremen.de/gruppen/molspec/index.html
; Spectral Resolution:	0.22 nm below 312.5 nm, 0.21 nm above 312.5 nm (FWHM)
; Number of data points in file:	1402
;
; ******** SO2 Absorption Cross Sections at 223K  at 100mbar ******************
; wave, vac  cross-section cm^2/molec
; ...
;   310.8179  3.732797E-19
;   310.9270  3.170747E-19
;   311.0360  2.727391E-19
;   311.1450  2.511800E-19
;   311.2540  2.270970E-19
;   311.3630  2.021375E-19
;   311.4720  1.688698E-19
;   311.5809  1.381238E-19
;   311.6899  1.179187E-19
;   311.7988  1.085289E-19
;   311.9077  1.096212E-19
;   312.0166  1.217833E-19
; ...
; ******** SO2 Absorption Cross Sections at 293K ******************
; ...
;   310.8179  3.361426E-19
;   310.9270  2.993402E-19
;   311.0360  2.659662E-19
;   311.1450  2.495556E-19
;   311.2540  2.293618E-19
;   311.3630  2.072764E-19
;   311.4720  1.797055E-19
;   311.5809  1.521881E-19
;   311.6899  1.331139E-19
;   311.7988  1.231006E-19
;   311.9077  1.214195E-19
;   312.0166  1.285237E-19

close,2 & openr,2,fname & so2_dat=dblarr(n_col,n_rows)
x='' & for i=0,n_header-1 do readf,2,x & readf,2,so2_dat & close,2 & print,x

l_v=1.00*reform(so2_dat(0,*)) & ml_v=n_elements(l_v) &  print,'ml_v=',ml_v
if w_units eq 'Angstrom' then l_v=0.1*l_v
Nlosch=2.686745D+19  &  so2v=Nlosch*reform(so2_dat(1,*))       ;       convert x-section to abs_coeff [atm-cm-1]

ENDELSE

return
end
