function sol_dist_kelly, jd
;======================================================================;
;                                                                      ;
;     FUNCTION :  sol_dist                                             ;
;     PURPOSE:                                                         ;
;       This function calculates the earth-sun distance (in A.U.)      ;
;     USE:                                                             ;
;            XXX = sol_dist (jd)                                       ;
;     PARAMETERS :                                                     ;
;                                                                      ;
;            XXX is the REAL*4 earth sun distance in A.U.              ;
;                                                                      ;
;            jd is the input parameter of the day number of            ;
;               the year (Jan 1 is 1, etc)                             ;
;                                                                      ;
;     SOURCE:            DONALD J. RICHARDSON                          ;
;                        HUGHES STX                                    ;
;                                                                      ;
;     LANGUAGE:          IDL                                           ;
;                                                                      ;
;     DATE STARTED :     January 5, 1995                               ;
;                                                                      ;
;     LATEST REVISION:   January 10, 1995                              ;
;                                                                      ;
;                                                                      ;
;======================================================================;
        on_error, 2

        if N_PARAMS() ne 1 then begin
          print,'The function SOL_DIST is called with the wrong number of'
          print,'parameters. The call should be:'
          print,'         distance_to_sun = sol_dist(day_number_of_year)'
          stop
        endif
;
;   Compute the earth-sun distance based on day of the year
;	Don Richardson's formula
;       g = 356.967 + 360.0/365.25 * ((jd mod 1000) + 0.5)
;       return, 1.0 - 0.0167 * cos(!pi * g / 180.0)
;------------   Tom Kelly' solar distance calculation
;-- We can easily check that the REFERENCE DAY-OF-YEAR, which is 3.4 in the
;-- above algorithm, is still fairly accurate.
;-- The net effect is about a 1.5% change in the Sun-Earth
;-- Distance, which yields an approximate 3% difference in the solar influx.

        sol_dist = 1.0 - 0.0167 *  COS((DOUBLE(jd)-3.4) * 1.7202423D-02)
;       sol_dist = 1.0 - 0.0167 * DCOS((DFLOAT(jd)-3.4) * 1.7202423D-02)

;       sol_dist_corr=1./ (sol_dist*sol_dist)
;       write(6,"(f9.5)") sol_dist
        print,'day  sol_dist', jd, sol_dist 	; formatwrite(6,"(f9.5)") sol_dist

        return, sol_dist

        end
