function triangle, x, y, base_size
;======================================================================;
;                                                                      ;
;     FUNCTION : triangle                                              ;
;                                                                      ;
;     PURPOSE:                                                         ;
;                                                                      ;
;         This function convolves a triangle function with a data set. ;
;                                                                      ;
;     USE:                                                             ;
;            result = triangle(x, y, base_size)                        ;
;                                                                      ;
;     PARAMETERS :                                                     ;
;                                                                      ;
;            result is the output of the convolution from this function;
;              result is the same size as the array, y.                ;
;                                                                      ;
;            x is the input array for the abscissa of the data set to  ;
;              process (used to the point spacing for the triangle     ;
;              function)                                               ;
;                                                                      ;
;            y is the input array for the ordinate of the data set to  ;
;              process.                                                ;
;                                                                      ;
;            base_size is the input scalar for the size of the base of ;
;              triangle.  The units of base_size are the same as the   ;
;              array, x.                                               ;
;                                                                      ;
;     SOURCE:            DONALD J. RICHARDSON                          ;
;                        HUGHES STX                                    ;
;                                                                      ;
;     LANGUAGE:          IDL                                           ;
;                                                                      ;
;     DATE STARTED :     January 10, 1995                              ;
;                                                                      ;
;     LATEST REVISION:   January 10, 1995                              ;
;                                                                      ;
;                                                                      ;
;======================================================================;
;
;   getting the average point spacing of the x array
;
  avg_val = avg(x(1:*) - x(0:*))
;
;   getting the number of points in the base of the triangle and the center
;
  num_point = fix(base_size/avg_val)
  if num_point mod 2 ne 1 then num_point = num_point + 1
  if num_point eq 0 then begin
    print,'Convolving over no point, unprocessed array returned.'
    return, y
  endif
  center = num_point/2
;
;   delta is the change in sucessive points in the triangle; edges are 0.0,
;   center is 1.0
;
  if center ne 0 then $
     delta = 1.0 / center $
  else $
     delta = 0.0
;
;   Creating the triangle array
;
  triangle_function = fltarr(num_point)
  if center ne 0 then $
    triangle_function(0:center - 1) = delta * findgen(center)
  triangle_function(center:*) = 1.0 - delta * (findgen(num_point - center))
  triangle_function = triangle_function / total(triangle_function)
;
;  convolving
;
  return, convol(y, triangle_function)
end
