;
;  read in bass ozone absorption coefficients and plot vs wavelength
;  calculate temperature sensitivities for variably selected triplet
;  combinations and plot the results.  The calculation is designed to
;  aid in optimization of channel selection to minimize temperature
;  dependence in triplet retrievals of ozone. It is lenghty.
;  When executing this code, press enter to see the next plot.
;
!x.charsize=1.5
!y.charsize=1.5
!p.charthick=1.5
!p.thick=1.5
!x.thick=1.5
!y.thick=1.5
;
;set_plot,'ps'
;device,filename='eptwav.ps'
;device,/encapsulated,filename='eptwav.eps'
cartrn=''
;
eptlms=[317.5,318.0]
eptlmm=[340.0]
eptlml=[388.0,383.0,393.5]
;
;  recover raman and flux from leslie
;
restore,'raman_flux.sav'
restore,'ringmoy.dat'
help,wave
help,perms
rings=interpol(perms(*,2),wave,eptlms)
ringm=interpol(perms(*,2),wave,eptlmm)
ringl=interpol(perms(*,2),wave,eptlml)
;
doring=1
if doring eq 1 then begin
;
set_plot,'ps'
device,/encapsulated,filename='triring.eps'
plot,wave,perms(*,2),xrange=[300,400],xstyle=1,yrange=[-4.0,4.0],ystyle=1, $
  xtitle='Wavelength (nm)',ytitle='Percent Radiance', $
  title='Nominal Ring Effect in Near Ultraviolet (1 nm)'
oplot,wave,denominator/500.0,linestyle=1
  x=[0.17,0.22] & y=[0.20,0.20]
  plots,x,y,linestyle=1,/normal
  xyouts,0.25,0.19,'Relative Flux',/normal,charsize=1.25
oplot,eptlms,rings,psym=2
oplot,eptlmm,ringm,psym=2
oplot,eptlml,ringl,psym=2
x=[300,400] & y=[0,0] & oplot,x,y
read,cartrn
device,/close
;
skprst = 1
if skprst eq 0 then begin
;
plot,wave,perms(*,2),xrange=[300,350],xstyle=1,yrange=[-4.0,4.0],ystyle=1, $
  xtitle='Wavelength (nm)',ytitle='Percent Radiance', $
  title='Ring Effect on OMPS Nadir Baseline Total Ozone Wavelengths'
oplot,wave,denominator/500.0,linestyle=1
  x=[0.17,0.22] & y=[0.20,0.20]
  plots,x,y,linestyle=1,/normal
  xyouts,0.25,0.19,'Relative Flux',/normal,charsize=1.25
oplot,eptlms,rings,psym=2
oplot,eptlmm,ringm,psym=2
x=[300,350] & y=[0,0] & oplot,x,y
read,cartrn
;
plot,wave,perms,xrange=[350,400],xstyle=1,yrange=[-4.0,4.0],ystyle=1, $
  xtitle='Wavelength (nm)',ytitle='Percent Radiance', $
  title='Ring Effect on OMPS Nadir Baseline Total Ozone Wavelengths'
oplot,wave,denominator/500.0,linestyle=1
  x=[0.17,0.22] & y=[0.20,0.20]
  plots,x,y,linestyle=1,/normal
  xyouts,0.25,0.19,'Relative Flux',/normal,charsize=1.25
oplot,eptlml,ringl,psym=2
x=[350,400] & y=[0,0] & oplot,x,y
read,cartrn
;
plot,wave,perms,xrange=[350,390],xstyle=1,yrange=[-1.5,1.5],ystyle=1, $
  xtitle='Wavelength (nm)',ytitle='Percent Radiance', $
  title='Ring Effect on OMPS Nadir Baseline Total Ozone Wavelengths'
oplot,wave,denominator/500.0-2.0,linestyle=1
  x=[0.17,0.22] & y=[0.20,0.20]
  plots,x,y,linestyle=1,/normal
  xyouts,0.25,0.19,'Relative Flux',/normal,charsize=1.25
oplot,eptlml,ringl,psym=2
x=[350,400] & y=[0,0] & oplot,x,y
read,cartrn
;
endif
;
endif
;
;  read in bass coefficients
;
data=fltarr(6,3047)
openr,1,'BASS_2.DAT'
readf,1,data
close,1
lamda=reform(data(0,*))
c0=reform(data(1,*))
c1=reform(data(2,*))
c2=reform(data(3,*))
beta=reform(data(4,*))
rhon=reform(data(5,*))
;
temp=0
alpha=c0+c1*temp+c2*temp*temp
sltalf = triangle(lamda,alpha,10.0)
;
temp=-48
alphat=c0+c1*temp+c2*temp*temp
sltalft = triangle(lamda,alphat,10.0)
;
temp=-58
alphat2=c0+c1*temp+c2*temp*temp
sltalft2 = triangle(lamda,alphat2,10.0)
;
x=[274.0,274.1] & y=interpol(sltalft,lamda/10.0,x) & print,y,(y(1)-y(0))/y(0)*100.0
plot,lamda/10.0,alpha,xrange=[334,346],xstyle=1,yrange=[0,0.6],ystyle=1
oplot,lamda/10.0,sltalf,linestyle=1
read,cartrn
;
alfplot=1
if alfplot eq 1 then begin
;
set_plot,'ps'
device,/encapsulated,filename='tritrip.eps'
plot,lamda/10.0,sltalft-sltalft2,xtitle='Wavelength (nm)', $
   xrange=[310,350],xstyle=1,yrange=[0,0.04],ystyle=1, $
   ytitle='Atm-cm -1'
;   ytitle='Atm-cm -1',Title='Change in Ozone Absorption with Temperature (1.0 nm)'
for i=0,0 do begin
  for j=0,0 do begin
    x1=[eptlmm(i),eptlml(j)] & y1=interpol(sltalft-sltalft2,lamda/10.0,x1)
    x2=[300.0,eptlmm(i),eptlml(j)] & y2=interpol(y1,x1,x2) & oplot,x2,y2
  endfor
endfor
x=eptlms & y=interpol(sltalft-sltalft2,lamda/10.0,x) & oplot,x,y,psym=2
x=eptlmm & y=interpol(sltalft-sltalft2,lamda/10.0,x) & oplot,x,y,psym=6
read,cartrn
device,/close
;
endif
;
;  calculate impact of temperature dependence on triplet (watch out for A - nm!)
;
;  identify nodes for calculations
;
ones=findgen(151)*0.2+305.0
delpoz=fltarr(151,4,4)
alfp=fltarr(151,4)
;
;  calculate temperature sensitivity for all nodes
;
calc1=1
if calc1 eq 1 then begin
;
for three=0,0 do begin
  for two=0,0 do begin
    for one=0,150 do begin
      trip=[ones(one),eptlmm(two),eptlml(three)]
      talft=interpol(sltalft,lamda,trip*10.0)
      talft2=interpol(sltalft2,lamda,trip*10.0)
      alfp(one,two)=talft(0)-talft(1)
;dela1=(talft2(0)-talft(0))
;dela2=(talft2(1)-talft(1))
;ratio=(trip(2)-trip(0))/(trip(2)-trip(1))
;      delpoz(one,two,three)=(((talft2(1)-talft(1))*(trip(2)-trip(0))/(trip(2)-trip(1)))- $
;            (talft2(0)-talft(0)))/alfp(one,two)*100.0
;
;  try simple pair calculation
;
      delpoz(one,two,three)=-((talft2(1)-talft(1))-(talft2(0)-talft(0)))/alfp(one,two)*100.0
;print,one,two,three
;print,trip
;print,'dela1,dela2,ratio,alfp(one,two),delpoz(one,two,three)'
;print,dela1,dela2,ratio,alfp(one,two),delpoz(one,two,three)
;read,cartrn
    endfor
  endfor
  istop=where(ones eq 323)
;
set_plot,'ps'
device,/encapsulated,filename='tritemp.eps'
  plot,ones(0:istop(0)),delpoz(0:istop(0),0,three),xtitle='Short Wavelength',ytitle='Percent Ozone per 10 Degrees', $
    title='Triplet Temperature Dependence', $
    xrange=[305,325],xstyle=1,yrange=[-6,2],ystyle=1
;eptlms=[308.65,312.56,317.57,322.37]
;          0      1      2      3
;  select short wavelengths for mid wavelength (331.0)
;  slct=[0,1,2,3]
  slct=[0,1]
  eptdel=interpol(delpoz(*,0,three),ones,eptlms(slct))
  oplot,eptlms(slct),eptdel,psym=2
print,eptlms
print,slct
print,eptlms(slct)
print,eptdel
read,cartrn
;for iprnt=0,6 do print,iprnt,eptlms(slct(iprnt)),eptdel(iprnt)
  x=[300,340] & y=[0,0] & oplot,x,y
;  istop=where(ones eq eptlmm(1))
;print,istop,ones(istop),eptlmm(1)
;  oplot,ones(0:istop(0)),delpoz(0:istop(0),1,three),linestyle=1
;  select short wavelengths for second mid wavelength (329.0)
;  slct=[6,9]
;  eptdel=interpol(delpoz(*,1,three),ones,eptlms(slct))
;  oplot,eptlms(slct),eptdel,psym=2
;for iprnt=0,1 do print,iprnt,eptlms(slct(iprnt)),eptdel(iprnt)
;  istop=where(ones eq eptlmm(2))
;print,istop,ones(istop),eptlmm(2)
;  oplot,ones(0:istop(0)),delpoz(0:istop(0),2,three),linestyle=2
;;  select short wavelengths for third mid wavelength (332.0)
;  slct=[11]
;  eptdel=interpol(delpoz(*,2,three),ones,eptlms(slct))
;  oplot,eptlms(slct),eptdel,psym=2
;for iprnt=0,0 do print,iprnt,eptlms(slct(iprnt)),eptdel(iprnt)
;  oplot,ones,delpoz(*,3,three),linestyle=3
;;  select short wavelengths for fourth mid wavelength (336.0)
;  slct=[8,12,13,14]
;  eptdel=interpol(delpoz(*,3,three),ones,eptlms(slct))
;  oplot,eptlms(slct),eptdel,psym=2
;for iprnt=0,3 do print,iprnt,eptlms(slct(iprnt)),eptdel(iprnt)
;;  select temperature sensitive short wavelength(321) for fourth mid wavelength (336.0)
;  slct=[10]
;  eptdel=interpol(delpoz(*,3,three),ones,eptlms(slct))
;  oplot,eptlms(slct),eptdel,psym=2
;  xyouts,eptlms(slct),eptdel,'T',alignment=0.5
;for iprnt=0,0 do print,iprnt,eptlms(slct(iprnt)),eptdel(iprnt)
;
;  x=[0.17,0.22] & y=[0.90,0.90]
;  plots,x,y,/normal
  trpstrng=string(eptlmm(0),eptlml(three),format="('Triplet with ',f5.1,' & ',f5.1)")
  xyouts,0.20,0.85,trpstrng,/normal,charsize=1.25
;  x=[0.17,0.22] & y=[0.85,0.85]
;  plots,x,y,linestyle=1,/normal
;  trpstrng=string(eptlmm(1),eptlml(three),format="('Triplet with ',f5.1,' & ',f5.1)")
;  xyouts,0.25,0.84,trpstrng,/normal,charsize=1.25
;  x=[0.17,0.22] & y=[0.80,0.80]
;  plots,x,y,linestyle=2,/normal
;  trpstrng=string(eptlmm(2),eptlml(three),format="('Triplet with ',f5.1,' & ',f5.1)")
;  xyouts,0.25,0.79,trpstrng,/normal,charsize=1.25
;  x=[0.17,0.22] & y=[0.75,0.75]
;  plots,x,y,linestyle=3,/normal
;  trpstrng=string(eptlmm(3),eptlml(three),format="('Triplet with ',f5.1,' & ',f5.1)")
;  xyouts,0.25,0.74,trpstrng,/normal,charsize=1.25
; x=[0.17,0.22] & y=[0.20,0.20]
; plots,x,y,linestyle=1,/normal
; xyouts,0.25,0.19,'Precision Threshold',/normal,charsize=1.25
  read,cartrn
device,/close
;
endfor
;
endif
;
;  create table of differential absorption for path length criteria
;
dotbl=0
if dotbl eq 1 then begin
;
eptlms=[308.65,312.56,317.57,322.37]
eptlmm=[331.29]

alfs=interpol(sltalft,lamda,eptlms*10.0) 
alfm=interpol(sltalft,lamda,eptlmm*10.0) 
dalf=alfs-alfm
order=reverse(sort(dalf))
dalf=dalf(order)
alfs=alfs(order)
alfm=alfm(order)
eptlms=eptlms(order)
eptlmm=eptlmm(order)
print,'       Short         Mid      Short Alpha  Delta Alpha'
for i=0,3 do print,eptlms(i),eptlmm(i),alfs(i),dalf(i)
print,'Short wavelength alpha'
print,' Lamda  0.75  1.00  1.25  1.50  1.75  2.00  2.50  3.00  3.50  4.00  5.00  6.00'
for i=0,3 do print,eptlms(i),alfs(i)*0.75,alfs(i),alfs(i)*1.25,alfs(i)*1.5,alfs(i)*1.75,alfs(i)*2, $
                alfs(i)*2.5,alfs(i)*3,alfs(i)*3.5,alfs(i)*4,alfs(i)*5,alfs(i)*6, $
                format='(f6.1,12f6.2)'
print,'Delta Alpha'
print,' Lamda  0.75  1.00  1.25  1.50  1.75  2.00  2.50  3.00  3.50  4.00  5.00  6.00'
for i=0,3 do print,eptlms(i),dalf(i)*0.75,dalf(i),dalf(i)*1.25,dalf(i)*1.5,dalf(i)*1.75,dalf(i)*2, $
                dalf(i)*2.5,dalf(i)*3,dalf(i)*3.5,dalf(i)*4,dalf(i)*5,dalf(i)*6, $
                format='(f6.1,12f6.2)'
print,' '
;
;  print table indicating path length regimes for various triplets
;
regimes=['   s < 0.75    ','   s < 1.00    ','   s < 1.25    ','0.75 < s < 1.50', $
         '1.00 < s < 1.75','   s < 2.00    ','1.25 < s < 2.50','1.50 < s < 2.50', $
         '1.75 < s < 3.50','   2.00 < s    ','2.50 < s < 5.00','   2.50 < s    ', $
         '   3.50 < s    ','   5.00 < s    ']
print,'Path Length Regimes for the Various Triplets (and triplet indeces)'
print,'  '
print,'     Index     Short         Mid      Delta Alpha     Path Length Range'
print,'                                            '
for i=0,3 do print,i+1,eptlms(i),eptlmm(i),dalf(i),'         '+regimes(i)
print,'                                            '
print,'Triplets are calculated using 367.0, 369.0, 370.5, and 372.0 alternately'
print,'with each short - mid pair.  The 321.0 - 331.0 and 322.5 - 332.0 triplets'
print,'will always be computed to monitor temperature dependence.'
print,'The 316.0 and 317.0 triplets are used to monitor the Ring correction.'
print,'Note that the 310.5 and 312.0 channels are sensitive and insensitive to SO2.'
;
;  print table in alternate form
;
regime2=['   s < 0.75    ','0.75 < s < 1.00','1.00 < s < 1.25','1.25 < s < 1.50', $
         '1.50 < s < 1.75','1.75 < s < 2.00','2.00 < s < 2.50','2.50 < s < 3.00', $
         '3.00 < s < 3.50','3.50 < s < 5.00','   5.00 < s    ']
trpinds=[' 1   2   3',' 2   3   4',' 3   4   5',' 4   5   7',' 5   7   8',' 7   8   9', $
        ' 7   8   9',' 9  11  12',' 9  11  12','11  12  13','12  13  14']
mixers=['none','none','none','  1 ','  2 ','  2 ','  4 ','  5 ','  8 ','  8 ','  9 ']
print,'  '
print,'Triplets and mixing channels to be used in the various path length regimes'
print,'  '
print,'            Path Length Range       Triplets Used        Mixing Channel'
for i=0,10 do print,i+1,regime2(i),trpinds(i),mixers(i),format='(i8,3a20)'
;
endif
;
;  estimate da/dl and plot with ept channels to check l cal sensitivity
;  (0.1 nm = 1.5% ozone at N7 TOMS 312.34 channel)
;
dodw=0
if dodw eq 1 then begin
;
info=size(sltalft)
dim=info(1)
help,sltalft
print,info
help,dim
dadlnp=(sltalft(1:dim-1)-sltalft(0:dim-2))/(lamda(1:dim-1)-lamda(0:dim-2))
dadl=dadlnp/((sltalft(1:dim-1)+sltalft(0:dim-2))/2)*100.0
dlmda=(lamda(1:dim-1)+lamda(0:dim-2))/2.0
help,dadl
help,dlmda
;
;  dlmda in A dadl in %/A estimated amplitude of spectral smile is 0.2 A
;
;x=eptlms-0.3
;for d=0,4 do begin
;x=x+0.1
;print,d
plot,dlmda/10.0,dadl/5.0,xtitle='Wavelength (nm)', $
   xrange=[310,340],xstyle=1,yrange=[-5.0,5.0],ystyle=1, $
   ytitle='dalfa/dlamda (% / 0.2 A)',Title='Change in Ozone Absorption with Wavelength (1.0 nm)'
;y=interpol(dadl/5.0,dlmda/10.0,x) & oplot,x,y,psym=2
x=eptlms & y=interpol(dadl/5.0,dlmda/10.0,x) & oplot,x,y,psym=2
x=eptlmm & y=interpol(dadl/5.0,dlmda/10.0,x) & oplot,x,y,psym=6
x1=[300,340] & y1=[0,0] & oplot,x1,y1
for i=0,3 do print,i,x(i),y(i)
read,cartrn
;endfor
;
plot,lamda/10.0,sltalft,xtitle='Wavelength (nm)', $
   xrange=[310,340],xstyle=1,yrange=[0,2],ystyle=1, $
   ytitle='Absorption (Atm-cm -1)',Title='Ozone Absorption vs. (1.0 nm)'
x=eptlms & y=interpol(sltalft,lamda/10.0,x) & oplot,x,y,psym=2
read,cartrn
;
plot,lamda/10.0,sltalft-sltalft2,xtitle='Wavelength (nm)', $
   xrange=[310,340],xstyle=1,yrange=[0,0.03],ystyle=1, $
   ytitle='Atm-cm -1 / 10 Degrees',Title='Change in Ozone Absorption with Temperature (1.0 nm)'
x=eptlms & y=interpol(sltalft-sltalft2,lamda/10.0,x) & oplot,x,y,psym=2
read,cartrn
;
plot,lamda/10.0,(sltalft-sltalft2)/sltalft*100.0,xtitle='Wavelength (nm)', $
   xrange=[310,340],xstyle=1,yrange=[0,10],ystyle=1, $
   ytitle='% / 10 Degrees',Title='Change in Ozone Absorption with Temperature (1.0 nm)'
x=eptlms & y=interpol((sltalft-sltalft2)/sltalft*100.0,lamda/10.0,x) & oplot,x,y,psym=2
read,cartrn
;
endif
;
;  calculate sensitivity to wavelength shift for all nodes
;  (substituting into alpha(T) code with dadl, alpha(delamda))
;
calc2=0
if calc2 eq 1 then begin
print,'starting calc2'
;
eptlms=[308.65,312.56,317.57,322.37]
eptlmm=[331.29]
;
for three=0,0 do begin
  for two=0,0 do begin
    for one=0,150 do begin
      trip=[ones(one),eptlmm(two),eptlml(three)]
      talft=interpol(sltalft,lamda,trip*10.0)
      talft2=interpol(sltalft(0:dim-2)+dadlnp/5.0,lamda(0:dim-2),trip*10.0)
      alfp(one,two)=talft(0)-talft(1)
;dela1=(talft2(0)-talft(0))
;dela2=(talft2(1)-talft(1))
;ratio=(trip(2)-trip(0))/(trip(2)-trip(1))
      delpoz(one,two,three)=(((talft2(1)-talft(1))*(trip(2)-trip(0))/(trip(2)-trip(1)))- $
            (talft2(0)-talft(0)))/alfp(one,two)*100.0
;print,one,two,three
;print,trip
;print,'dela1,dela2,ratio,alfp(one,two),delpoz(one,two,three)'
;print,dela1,dela2,ratio,alfp(one,two),delpoz(one,two,three)
;read,cartrn
    endfor
  endfor
  istop=where(ones eq eptlmm(0))
print,istop,ones(istop),eptlmm(0)
;
;set_plot,'ps'
;device,/encapsulated,filename='dellam.eps'
;
  plot,ones(0:istop(0)),delpoz(0:istop(0),0,three), $
    xtitle='Short Wavelength',ytitle='Percent Ozone per 0.2 A', $
;    title='Triplet Wavelength Calibration Dependence', $
    xrange=[300,340],xstyle=1,yrange=[-6,6],ystyle=1
read,cartrn
;eptlms=[308.65,312.56,317.57,322.37]
;          0      1      2      3
;
;  select short wavelengths for first mid wavelength (321.0)
  slct=[0,1,2,3]
  eptdel=interpol(delpoz(*,0,three),ones,eptlms(slct))
  oplot,eptlms(slct),eptdel,psym=2
print,'Errors from 1st Mid'
for iprt=0,6 do print,iprt,eptlms(slct(iprt)),eptdel(iprt)
  x=[300,340] & y=[0,0] & oplot,x,y
;  x=[300,340] & y=[0.4,0.4] & oplot,x,y,linestyle=1
;  x=[300,340] & y=[-0.4,-0.4] & oplot,x,y,linestyle=1
;  x=[300,340] & y=[1.6,1.6] & oplot,x,y,linestyle=1
;  x=[300,340] & y=[-1.6,-1.6] & oplot,x,y,linestyle=1
  istop=where(ones eq eptlmm(1))
print,istop,ones(istop),eptlmm(1)
  oplot,ones(0:istop(0)),delpoz(0:istop(0),1,three),linestyle=1
read,cartrn
;
  x=[0.17,0.22] & y=[0.90,0.90]
  plots,x,y,/normal
  trpstrng=string(eptlmm(0),eptlml(three),format="('Triplet with ',f5.1,' & ',f5.1)")
  xyouts,0.25,0.89,trpstrng,/normal,charsize=1.25
  read,cartrn
;
;device,/close
;
endfor
;
endif
;
;device,/close
end
